// Get DOM elements
const usernameInput = document.getElementById('username');
const chatHistory = document.getElementById('chatHistory');
const userInput = document.getElementById('userInput');
const sendButton = document.getElementById('sendButton');
const trainPrompt = document.getElementById('trainPrompt');
const trainResponse = document.getElementById('trainResponse');
const trainButton = document.getElementById('trainButton');
const trainWithAIButton = document.getElementById('trainWithAIButton');
const aiChatHistory = document.getElementById('aiChatHistory');

// OpenRouter API key
const OPENROUTER_API_KEY = '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';

// Function to add a message to the chat history
function addMessageToChat(username, message, isAI = false) {
    const messageDiv = document.createElement('div');
    messageDiv.classList.add('message');
    messageDiv.classList.add(isAI ? 'ai-message' : 'user-message');

    const sender = document.createElement('strong');
    sender.textContent = isAI ? 'TokTok AI' : username;

    const messageText = document.createElement('p');
    messageText.textContent = message;

    messageDiv.appendChild(sender);
    messageDiv.appendChild(messageText);
    chatHistory.appendChild(messageDiv);

    // Scroll to the bottom of the chat history
    chatHistory.scrollTop = chatHistory.scrollHeight;
}

// Function to add a message to the AI-to-AI chat history
function addAIChatMessage(message, isExternalAI = false) {
    const messageDiv = document.createElement('div');
    messageDiv.classList.add('message');
    messageDiv.classList.add(isExternalAI ? 'external-ai-message' : 'our-ai-message');

    const sender = document.createElement('strong');
    sender.textContent = isExternalAI ? 'External AI' : 'Our AI';

    const messageText = document.createElement('p');
    messageText.textContent = message;

    messageDiv.appendChild(sender);
    messageDiv.appendChild(messageText);
    aiChatHistory.appendChild(messageDiv);

    // Scroll to the bottom of the AI chat history
    aiChatHistory.scrollTop = aiChatHistory.scrollHeight;
}

// Function to send a message to OpenRouter AI
async function sendToOpenRouter(prompt) {
    try {
        const response = await fetch('https://openrouter.ai/api/v1/chat/completions', {
            method: 'POST',
            headers: {
                'Authorization': `Bearer ${OPENROUTER_API_KEY}`,
                'Content-Type': 'application/json',
                'HTTP-Referer': 'http://thomaslopezforte.searchcontent.tech:9200/', // Optional
                'X-Title': 'TokTok AI Chatbot', // Optional
            },
            body: JSON.stringify({
                model: 'qwen/qwen2.5-vl-72b-instruct:free', // Use the specified model
                messages: [
                    {
                        role: 'user',
                        content: prompt,
                    },
                ],
            }),
        });

        if (!response.ok) {
            throw new Error(`Failed to fetch response from OpenRouter AI. Status: ${response.status}`);
        }

        const data = await response.json();
        console.log('API Response:', data); // Log the API response
        return data.choices[0].message.content; // Return the AI's response
    } catch (error) {
        console.error('Error sending message to OpenRouter AI:', error);
        return 'Error: Could not generate a response.';
    }
}

// Function to handle the "Train with AI" button
// Function to handle the "Train with AI" button
trainWithAIButton.addEventListener('click', async function () {
    // Disable the button to prevent multiple clicks
    trainWithAIButton.disabled = true;
    trainWithAIButton.textContent = 'AI Conversation in Progress...';

    // Predefined prompts for the AI-to-AI conversation
    const predefinedPrompts = [
        "Hello, how are you?",
        "What is the capital of France?",
        "Explain the theory of relativity.",
        "What is the meaning of life?",
    ];

    // Simulate AI-to-AI conversation
    for (const prompt of predefinedPrompts) {
        // External AI sends a message
        const externalAIResponse = await sendToOpenRouter(prompt);
        addAIChatMessage(externalAIResponse, true);

        // Simulate a delay for the main AI's response
        await new Promise((resolve) => setTimeout(resolve, 1000));

        // Main AI generates a response
        const mainAIResponse = await fetch('http://thomaslopezforte.searchcontent.tech:9200/generate-response', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({ prompt: externalAIResponse }),
        })
            .then((res) => res.json())
            .then((data) => data.response)
            .catch((err) => 'Error generating response.');

        // Main AI sends a response
        addAIChatMessage(mainAIResponse, false);

        // Save the conversation to the training data
        await saveTrainingData(prompt, externalAIResponse);
        await saveTrainingData(externalAIResponse, mainAIResponse);

        // Simulate a delay before the next message
        await new Promise((resolve) => setTimeout(resolve, 1000));
    }

    // Re-enable the button
    trainWithAIButton.disabled = false;
    trainWithAIButton.textContent = 'Train with AI';
});

// Function to save training data
async function saveTrainingData(prompt, response) {
    await fetch('http://thomaslopezforte.searchcontent.tech:9200/train', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ prompt, response }),
    })
        .then((res) => {
            if (!res.ok) {
                throw new Error('Network response was not ok.');
            }
            return res.text();
        })
        .then((data) => {
            console.log(data); // Log success message
        })
        .catch((err) => {
            console.error('Error saving training data:', err);
        });
}

// Function to handle the "Send" button
function sendMessage() {
    const username = usernameInput.value.trim();
    const message = userInput.value.trim();

    if (!username) {
        alert('Please enter a username.');
        return;
    }

    if (!message) {
        alert('Please enter a message.');
        return;
    }

    // Add the user's message to the chat history
    addMessageToChat(username, message);

    // Send the message to the backend
    fetch('http://thomaslopezforte.searchcontent.tech:9200/generate-response', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ prompt: message }),
    })
        .then((res) => {
            if (!res.ok) {
                throw new Error('Network response was not ok.');
            }
            return res.json();
        })
        .then((data) => {
            // Add the AI's response to the chat history
            addMessageToChat(username, data.response, true);

            // Save the chat to the server
            saveChatToServer(username, message, data.response);
        })
        .catch((err) => {
            console.error('Error generating response:', err);
            addMessageToChat('System', 'Error: Could not generate a response.', true);
        });

    // Clear the input field
    userInput.value = '';
}

// Function to save the chat to the server
function saveChatToServer(username, prompt, response) {
    fetch('http://thomaslopezforte.searchcontent.tech:9200/save-chat', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ username, prompt, response }),
    })
        .then((res) => {
            if (!res.ok) {
                throw new Error('Network response was not ok.');
            }
            return res.text();
        })
        .then((data) => {
            console.log(data); // Log success message
        })
        .catch((err) => {
            console.error('Error saving chat:', err);
        });
}

// Function to handle the "Train" button
trainButton.addEventListener('click', function () {
    const prompt = trainPrompt.value.trim();
    const response = trainResponse.value.trim();

    if (!prompt || !response) {
        alert('Please enter both a prompt and a response.');
        return;
    }

    // Send the training data to the backend
    fetch('http://thomaslopezforte.searchcontent.tech:9200/train', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ prompt, response }),
    })
        .then((res) => {
            if (!res.ok) {
                throw new Error('Network response was not ok.');
            }
            return res.text();
        })
        .then((data) => {
            console.log(data); // Log success message
            alert('Training data saved successfully!');
        })
        .catch((err) => {
            console.error('Error saving training data:', err);
            alert('Error: Could not save training data.');
        });

    // Clear the training input fields
    trainPrompt.value = '';
    trainResponse.value = '';
});

// Event listener for the Send button
sendButton.addEventListener('click', sendMessage);

// Allow pressing Enter to send the message
userInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
        sendMessage();
    }
});