const express = require('express');
const axios = require('axios');
require('dotenv').config(); // Load environment variables

const app = express();
const PORT = 3000;

// Middleware to parse JSON requests
app.use(express.json());

// Serve static files (HTML, CSS, JS) from the "public/ai" folder
app.use(express.static('public/ai'));

// Endpoint to interact with the OpenRouter API
app.post('/api/all', async (req, res) => {
  try {
    const { message, file } = req.body;

    // Validate input
    if (!message && !file) {
      return res.status(400).json({ error: 'Message or file is required.' });
    }

    // OpenRouter API configuration
    const OPENROUTER_API_KEY = process.env.OPENROUTER_API_KEY;
    const OPENROUTER_API_URL = 'https://openrouter.ai/api/v1/chat/completions';

    // Prepare the request payload
    const messages = [];
    if (message) {
      messages.push({ role: 'user', content: [{ type: 'text', text: message }] });
    }
    if (file) {
      messages.push({
        role: 'user',
        content: [
          { type: 'image_url', image_url: { url: file } } // Send file as base64
        ]
      });
    }

    // Make a request to the OpenRouter API
    const response = await axios.post(OPENROUTER_API_URL, {
      model: 'qwen/qwen2.5-vl-72b-instruct:free',
      messages,
    }, {
      headers: {
        'Authorization': `Bearer ${OPENROUTER_API_KEY}`,
      },
    });

    // Extract and send the AI's response
    const aiResponse = response.data.choices[0].message.content;
    res.json({ response: aiResponse });
  } catch (error) {
    console.error('Error calling OpenRouter API:', error.message);
    res.status(500).json({ error: 'Failed to fetch response from AI.' });
  }
});

// Start the server
app.listen(PORT, () => {
  console.log(`Server is running on port ${PORT}`);
});