const express = require('express');
const axios = require('axios');
const marked = require('marked'); // Import marked.js
require('dotenv').config();

const app = express();
const PORT = 3000;

app.use(express.json());
app.use(express.static('public/ai'));

app.post('/api/flagship', async (req, res) => {
    try {
        const { message } = req.body;

        if (!message) {
            return res.status(400).json({ error: 'Message is required.' });
        }

        const OPENROUTER_API_KEY = process.env.OPENROUTER_API_KEY;
        const OPENROUTER_API_URL = 'https://openrouter.ai/api/v1/chat/completions';

        const response = await axios.post(OPENROUTER_API_URL, {
            model: 'google/gemini-2.0-flash-exp:free', // Choose your model
            messages: [{ role: 'user', content: message }],
        }, {
            headers: {
                'Authorization': `Bearer ${OPENROUTER_API_KEY}`,
                'Content-Type': 'application/json',
            },
        });

        const aiResponse = response.data.choices[0].message.content;

        // Convert Markdown to HTML using marked
        const formattedResponse = marked.parse(aiResponse);

        res.json({ response: formattedResponse });

    } catch (error) {
        console.error('Error calling OpenRouter API:', error.message);
        res.status(500).json({ error: 'Failed to fetch response from AI.' });
    }
});

app.listen(PORT, () => {
    console.log(`Server is running on port ${PORT}`);
});