const express = require('express');
const axios = require('axios');
const marked = require('marked'); // Import marked.js
require('dotenv').config();

const app = express();
const PORT = 3000;

app.use(express.json());
app.use(express.static('public/ai'));

app.post('/api/flagship', async (req, res) => {
    try {
        const { message, imageUrl } = req.body;

        if (!message && !imageUrl) {
            return res.status(400).json({ error: 'Message or image URL is required.' });
        }

        const OPENROUTER_API_KEY = process.env.OPENROUTER_API_KEY;
        const OPENROUTER_API_URL = 'https://openrouter.ai/api/v1/chat/completions';

        const messages = [];
        if (message) {
            messages.push({ role: 'user', content: [{ type: 'text', text: message }] });
        }
        if (imageUrl) {
            messages.push({
                role: 'user',
                content: [
                    { type: 'image_url', image_url: { url: imageUrl } }
                ]
            });
        }

        const response = await fetch('https://thomaslopezforte.searchcontent.tech/api/flagship', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({ message: userInput })
        });

        const aiResponse = response.data.choices[0].message.content;

        // Convert Markdown to HTML
        const formattedResponse = marked.parse(aiResponse);

        res.json({ response: formattedResponse });

    } catch (error) {
        console.error('Error calling OpenRouter API:', error.message);
        res.status(500).json({ error: 'Failed to fetch response from AI.' });
    }
});

app.listen(PORT, () => {
    console.log(`Server is running on port ${PORT}`);
});