const express = require('express');
const path = require('path');
const fs = require('fs');
const app = express();

// Serve static files from the "public" directory
app.use(express.static(path.join(__dirname, 'public')));

// API endpoint to fetch the view count
app.get('/api/viewcount', (req, res) => {
  fs.readFile('viewcount.json', 'utf8', (err, data) => {
    if (err) {
      console.error('Error reading viewcount.json:', err);
      return res.status(500).json({ error: 'Unable to fetch view count' });
    }
    const viewCount = JSON.parse(data);
    res.json(viewCount);
  });
});

// Catch-all route for 404 errors
app.use((req, res) => {
  res.status(404).sendFile(path.join(__dirname, 'public', '404.html'));
});

// Start the server
const PORT = process.env.PORT || 3000;
app.listen(PORT, () => {
  console.log(`Server is running on port ${PORT}`);
});